@@ -1,9 +1,6 @@
-use 5.005003;
+use strict; use warnings;
 package boolean;
-use strict;
-
-$boolean::VERSION = '0.29';
-
+$boolean::VERSION = '0.31';
 my ($true, $false);
 
 use overload
@@ -79,7 +76,7 @@ sub truth {
     &Internals::SvREADONLY( \ !!1, 1);
 }
 
-sub TO_JSON() { ${$_[0]} ? \1 : \0 }
+sub TO_JSON { ${$_[0]} ? \1 : \0 }
 
 1;
 
@@ -230,13 +227,23 @@ Prints:
 
 C<-truth> can be used with the other import options.
 
+=head1 JSON SUPPORT
+
+JSON.pm will encode Perl data with boolean.pm values correctly if you use the
+C<convert_blessed> option:
+
+    use JSON;
+    use boolean -truth;
+    my $json = JSON->new->convert_blessed;
+    say $json->encode({false => (0 == 1)});     # Says: '{"false":false}',
+
 =head1 AUTHOR
 
 Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2007, 2008, 2010, 2011, 2013. Ingy döt Net.
+Copyright (c) 2007, 2008, 2010, 2011, 2013, 2014. Ingy döt Net.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
